@@ -7,13 +7,9 @@ module ApolloUploadServer
     graphql_name "Upload"
 
     def self.coerce_input(value, _ctx)
-      raise GraphQL::CoercionError, "#{value.inspect} is not a valid upload" unless value.nil? || value.is_a?(::ApolloUploadServer::Wrappers::UploadedFile)
+      return super if value.nil? || value.is_a?(::ApolloUploadServer::Wrappers::UploadedFile)
 
-      value
-    end
-
-    def self.coerce_result(value, _ctx)
-      value
+      raise GraphQL::CoercionError, "#{value.inspect} is not a valid upload"
     end
   end
 end
